@@ -10,48 +10,17 @@ has 'attrName' =>
 	isa => "Str",
 	;
 
-has 'nodeName_attr' =>
-	is => "rw",
-	;
-
-has 'xmlns_attr' =>
-	is => "rw",
-	;
-
-has 'extra' =>
-	is => "ro",
-	isa => "ArrayRef",
-	lazy => 1,
-	default => sub {
-		my $self = shift;
-		my @extra;
-		if ( $self->nodeName_attr ) {
-			push @extra, "";
-		}
-		else {
-			push @extra, undef;
-		}
-		if ( $self->xmlns_attr ) {
-			push @extra, "";
-		}
-		elsif ( !defined $extra[0] ) {
-			pop @extra;
-		}
-		\@extra;
-	};
-
 method node_ok( XML::LibXML::Node $node, PRANG::Graph::Context $ctx ) {
-	( $node->nodeType == XML_TEXT_NODE or
-		  $node->nodeType == XML_CDATA_SECTION_NODE )
-		? 1 : undef;
+	return ( $node->nodeType == XML_TEXT_NODE or
+			 $node->nodeType == XML_CDATA_SECTION_NODE );
 }
 
 method accept( XML::LibXML::Node $node, PRANG::Graph::Context $ctx ) {
 	if ( $node->nodeType == XML_TEXT_NODE ) {
-		($self->attrName, $node->data, @{$self->extra});
+		($self->attrName, $node->data);
 	}
 	elsif ( $node->nodeType == XML_CDATA_SECTION_NODE ) {
-		($self->attrName, $node->data, @{$self->extra});
+		($self->attrName, $node->data);
 	}
 	else {
 		$ctx->exception("expected text node", $node);
@@ -74,7 +43,6 @@ method output ( Object $item, XML::LibXML::Element $node, PRANG::Graph::Context
 	if ( ref $value ) {
 		$value = $value->[$slot];
 	}
-	return unless length($value//"");
 	my $doc = $node->ownerDocument;
 	my $tn = $doc->createTextNode($value);
 	$node->appendChild($tn);
