@@ -21,6 +21,14 @@ has 'class' =>
 	is => "ro",
 	required => 1,
 	handles => [qw(marshall_in_element to_libxml)],
+	trigger => sub {
+		my $self = shift;
+		my $class = $self->class;
+		if ( !$class->can("marshall_in_element") ) {
+			$class = $class->name if ref $class;
+			die "Can't marshall $class; didn't 'use PRANG::Graph' ?";
+		}
+	},
 	;
 
 our %marshallers;  # could use MooseX::NaturalKey?
@@ -96,9 +104,9 @@ method parse( Str $xml ) {
 
 	my $context = PRANG::Graph::Context->new(
 		base => $self,
-		xpath => "/".$rootNode->nodeName,
+		xpath => "",
 		xsi => $xsi,
-		prefix => ($rootNode->prefix||""),
+		prefix => "",
 	       );
 
 	my $rv = $self->class->marshall_in_element(
